@@ -14,23 +14,23 @@ urlpatterns = patterns('',
         view=views.DocumentListView.as_view(),
         name="document_list"
     ),
-    url(
-        regex=r'^(?P<app_label>[_\-\w]+)/(?P<document_name>[_\-\w]+)/(?P<id>[\w]{24})/$',
-        view=views.DocumentDetailView.as_view(),
-        name="document_detail"
-    ),
-    url(
-        regex=r'^(?P<app_label>[_\-\w]+)/(?P<document_name>[_\-\w]+)/(?P<id>[\w]{24})/edit/$',
-        view=views.DocumentEditFormView.as_view(),
-        name="document_detail_edit_form"
-    ),
     url(
         regex=r'^(?P<app_label>[_\-\w]+)/(?P<document_name>[_\-\w]+)/add/$',
         view=views.DocumentAddFormView.as_view(),
         name="document_detail_add_form"
     ),
     url(
-        regex=r'^(?P<app_label>[_\-\w]+)/(?P<document_name>[_\-\w]+)/(?P<id>[\w]{24})/delete/$',
+        regex=r'^(?P<app_label>[_\-\w]+)/(?P<document_name>[_\-\w]+)/(?P<id>[\w]+)/$',
+        view=views.DocumentDetailView.as_view(),
+        name="document_detail"
+    ),
+    url(
+        regex=r'^(?P<app_label>[_\-\w]+)/(?P<document_name>[_\-\w]+)/(?P<id>[\w]+)/edit/$',
+        view=views.DocumentEditFormView.as_view(),
+        name="document_detail_edit_form"
+    ),
+    url(
+        regex=r'^(?P<app_label>[_\-\w]+)/(?P<document_name>[_\-\w]+)/(?P<id>[\w]+)/delete/$',
         view=views.DocumentDeleteView.as_view(),
         name="document_delete"
     )
